==> ah-formbuilder-1.0.61.tgz: package/es/components/toolbar/field-forms/TextField.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import SimpleTabs from "../../../utils/Tabs/SimpleTabs";
import TextInput from "../../../utils/inputs/TextInput";
import SearchableSelect from "../../../utils/selects/SearchableSelect";
import ValidateField from "../../../utils/validations/ValidateField";
import Button from "@material-ui/core/Button";
import { disableFieldEdit as _disableFieldEdit } from "../../../actions/toolbarActions";
import { createField as _createField, deleteField as _deleteField, updateField as _updateField, deleteNewField as _deleteNewField } from "../../../actions/formActions";
import { connect } from "react-redux";
import ConditionalLogic from "../../../utils/conditional-logic";
import { Scrollbars } from 'react-custom-scrollbars';
import { getHeight } from '../../../utils/helpers';
import { textFieldsConfigs } from './utils/textFieldConfigs';
import FieldRenderer from './utils/FieldRenderer';
import { processLocalFields } from './utils/helpers';
import axios from "axios";
var basicTabTitle = {
  en: 'Basic Settings',
  ar: 'الإعدادات الأساسية'
};
var advanceTabTitle = {
  en: 'Advance Settings',
  ar: 'إعدادات متقدمة'
};
var machineNameLabel = {
  en: 'Machine Name/Field ID',
  ar: 'إسم الألة'
};
var validationRegexLabel = {
  en: 'Validation Regex',
  ar: 'Regex للتحقق من الصحة'
};
var visibilityLabel = {
  en: 'Visibility to Employee',
  ar: 'الرؤية للموظف'
};
var cancelLabel = {
  en: 'Cancel',
  ar: 'إلغاء'
};
var saveLabel = {
  en: 'Save',
  ar: 'حفظ'
};
var visibleLabel = {
  en: 'Visible',
  ar: 'مرئي'
};
var hiddenLabel = {
  en: 'Hidden',
  ar: 'مختفي'
};

var TextField = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(TextField, _React$Component);

  function TextField(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "handleTabChange", function (e, newValue) {
      _this.setState({
        activeTab: newValue
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleDataChange", function (val, name) {
      var _this$setState;

      _this.setState((_this$setState = {}, _this$setState[name] = val, _this$setState.errors = {}, _this$setState));
    });

    _defineProperty(_assertThisInitialized(_this), "saveField", function () {
      _this.setState(_extends({}, _this.state, {
        isSaving: true
      }));

      var _this$state = _this.state,
          name = _this$state.name,
          machineName = _this$state.machineName,
          order = _this$state.order,
          conditionalLogic = _this$state.conditionalLogic,
          isRequired = _this$state.isRequired,
          isRichText = _this$state.isRichText,
          maxLength = _this$state.maxLength,
          placeholder = _this$state.placeholder,
          helpText = _this$state.helpText,
          subType = _this$state.subType,
          regex = _this$state.regex,
          regexErrMsg = _this$state.regexErrMsg,
          visibility = _this$state.visibility,
          uuid = _this$state.uuid,
          type = _this$state.type,
          parentId = _this$state.parentId;
      var newField = {
        name: name,
        machineName: machineName,
        order: order,
        uuid: uuid,
        type: type,
        parentId: parentId,
        config: {
          conditionalLogic: conditionalLogic,
          isConditionalEnabled: !!conditionalLogic.conditions.length,
          isRequired: isRequired,
          isRichText: isRichText,
          maxLength: maxLength,
          placeholder: placeholder,
          helpText: helpText,
          subType: subType,
          regex: regex,
          regexErrMsg: regexErrMsg,
          visibility: visibility
        }
      };
      var data = {
        field: newField
      };
      newField.locals = processLocalFields(_this.props.locals, _this.state);
      data.locals = processLocalFields(_this.props.locals, _this.state);
      ValidateField(newField, _this.props.fields, _this.props.currentLang).then( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _this.props.updateField(newField);

                _context.next = 3;
                return axios.post(_this.props.predefinedEndpoint + "/form/field/" + _this.props.formId, data);

              case 3:
                // await  axios.post(` ${this.props.predefinedEndpoint}/v2/form/field/${this.props.formId}`, data);
                _this.props.disableFieldEdit();

                _this.setState(_extends({}, _this.state, {
                  isSaving: false
                }));

              case 5:
              case "end":
                return _context.stop();
            }
          }
        }, _callee);
      })))["catch"](function (errors) {
        var keys = Object.keys(errors);

        if (keys[0] === 'machineName' || keys[0] === 'conditionalLogic' || keys[0] === 'regex') {
          _this.handleTabChange({}, 'advance');
        } else {
          _this.handleTabChange({}, 'basic');
        }

        _this.setState({
          errors: errors,
          isSaving: false
        });
      });
    });

    _defineProperty(_assertThisInitialized(_this), "cancelEdit", function () {
      _this.props.deleteNewField();

      _this.props.disableFieldEdit();
    });

    _defineProperty(_assertThisInitialized(_this), "renderTabFields", function () {
      if (_this.state.activeTab === 'basic') {
        if (_this.state.subType === 'number' || _this.state.subType === 'email') {
          textFieldsConfigs.isRichText.configs.hidden = true;
        } else {
          textFieldsConfigs.isRichText.configs.hidden = false;
        }

        return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(FieldRenderer, _extends({}, _this.state, {
          locals: _this.props.locals,
          fieldConfigs: textFieldsConfigs,
          handleDataChange: _this.handleDataChange
        })));
      } else {
        return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4"
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.machineName,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'machineName');
          },
          label: machineNameLabel[_this.props.currentLang],
          required: true,
          autoFocus: true,
          error: _this.state.errors.machineName
        })), /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4"
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.regex,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'regex');
          },
          label: validationRegexLabel[_this.props.currentLang],
          required: false,
          error: _this.state.errors.regex
        })), _this.state.regex && _this.state.regex !== '' ? /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4"
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.regexErrMsg,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'regexErrMsg');
          },
          label: "Regex Validation Error Msg",
          required: false
        })) : "", /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4"
        }, /*#__PURE__*/React.createElement(SearchableSelect, {
          options: [{
            label: visibleLabel[_this.props.currentLang],
            value: 'visible'
          }, {
            label: hiddenLabel[_this.props.currentLang],
            value: 'hidden'
          }],
          label: visibilityLabel[_this.props.currentLang],
          value: _this.state.visibility ? 'visible' : 'hidden',
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value === 'visible', 'visibility');
          }
        })), /*#__PURE__*/React.createElement(ConditionalLogic, {
          predefined: _this.props.predefined,
          conditionalLogic: _this.state.conditionalLogic,
          isConditionalEnabled: _this.state.isConditionalEnabled,
          handleChange: _this.handleDataChange,
          errors: _this.state.errors.conditionalLogic ? _this.state.errors.conditionalLogic : []
        }));
      }
    });

    _this.state = _extends({
      activeTab: 'basic',
      errors: {},
      uuid: props.data.uuid,
      name: props.data.name,
      order: props.data.order,
      type: props.data.type,
      parentId: props.data.parentId,
      machineName: props.data.machineName,
      isSaving: false
    }, props.data.config);
    return _this;
  }

  var _proto = TextField.prototype;

  _proto.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    if (nextProps.data.uuid !== this.state.uuid) {
      this.setState(_extends({
        activeTab: 'basic',
        errors: {},
        uuid: nextProps.data.uuid,
        name: nextProps.data.name,
        order: nextProps.data.order,
        type: nextProps.data.type,
        parentId: nextProps.data.parentId,
        machineName: nextProps.data.machineName,
        isSaving: false
      }, nextProps.data.config));
    }
  };

  _proto.render = function render() {
    return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(SimpleTabs, {
      value: this.state.activeTab,
      handleChange: this.handleTabChange,
      options: [{
        label: basicTabTitle[this.props.currentLang],
        value: 'basic'
      }, {
        label: advanceTabTitle[this.props.currentLang],
        value: 'advance'
      }]
    }), /*#__PURE__*/React.createElement(Scrollbars, {
      style: {
        height: getHeight(true, true)
      },
      autoHide: true
    }, /*#__PURE__*/React.createElement("div", {
      className: "ahfb-p-3 ahfb-my-3"
    }, this.renderTabFields(), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-width-full ahfb-text-right"
    }, /*#__PURE__*/React.createElement(Button, {
      variant: "outlined",
      className: "ahfb-mr-2",
      onClick: this.cancelEdit
    }, cancelLabel[this.props.currentLang]), /*#__PURE__*/React.createElement(Button, {
      variant: "contained",
      disableElevation: true,
      disabled: this.state.isSaving,
      onClick: this.saveField
    }, saveLabel[this.props.currentLang])))));
  };

  return TextField;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    fields: state.form.data,
    operation: state.toolbar.operation,
    predefined: state.form.predefined,
    locals: state.form.locals,
    formId: state.form.formId,
    predefinedEndpoint: state.form.predefinedEndpoint,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    },
    deleteNewField: function deleteNewField() {
      return dispatch(_deleteNewField());
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    updateField: function updateField(data) {
      return dispatch(_updateField(data));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(TextField);

==> ah-formbuilder-1.0.71.tgz: package/es/components/toolbar/field-forms/TextField.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
var _jsxFileName = "/home/zaman/Documents/GitLab/bayt/formbuilder/src/components/toolbar/field-forms/TextField.js";

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import SimpleTabs from "../../../utils/Tabs/SimpleTabs";
import TextInput from "../../../utils/inputs/TextInput";
import SearchableSelect from "../../../utils/selects/SearchableSelect";
import ValidateField from "../../../utils/validations/ValidateField";
import Button from "@material-ui/core/Button";
import { disableFieldEdit as _disableFieldEdit } from "../../../actions/toolbarActions";
import { createField as _createField, deleteField as _deleteField, updateField as _updateField, deleteNewField as _deleteNewField } from "../../../actions/formActions";
import { connect } from "react-redux";
import ConditionalLogic from "../../../utils/conditional-logic";
import { Scrollbars } from 'react-custom-scrollbars';
import { getHeight } from '../../../utils/helpers';
import { textFieldsConfigs } from './utils/textFieldConfigs';
import FieldRenderer from './utils/FieldRenderer';
import { processLocalFields } from './utils/helpers';
import axios from "axios";
var basicTabTitle = {
  en: 'Basic Settings',
  ar: 'الإعدادات الأساسية'
};
var advanceTabTitle = {
  en: 'Advance Settings',
  ar: 'إعدادات متقدمة'
};
var machineNameLabel = {
  en: 'Machine Name/Field ID',
  ar: 'إسم الألة'
};
var validationRegexLabel = {
  en: 'Validation Regex',
  ar: 'Regex للتحقق من الصحة'
};
var visibilityLabel = {
  en: 'Visibility to Employee',
  ar: 'الرؤية للموظف'
};
var cancelLabel = {
  en: 'Cancel',
  ar: 'إلغاء'
};
var saveLabel = {
  en: 'Save',
  ar: 'حفظ'
};
var visibleLabel = {
  en: 'Visible',
  ar: 'مرئي'
};
var hiddenLabel = {
  en: 'Hidden',
  ar: 'مختفي'
};

var TextField = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(TextField, _React$Component);

  function TextField(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "handleTabChange", function (e, newValue) {
      _this.setState({
        activeTab: newValue
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleDataChange", function (val, name) {
      var _this$setState;

      _this.setState((_this$setState = {}, _this$setState[name] = val, _this$setState.errors = {}, _this$setState));
    });

    _defineProperty(_assertThisInitialized(_this), "saveField", function () {
      _this.setState(_extends({}, _this.state, {
        isSaving: true
      }));

      var _this$state = _this.state,
          name = _this$state.name,
          machineName = _this$state.machineName,
          order = _this$state.order,
          conditionalLogic = _this$state.conditionalLogic,
          isRequired = _this$state.isRequired,
          isRichText = _this$state.isRichText,
          maxLength = _this$state.maxLength,
          placeholder = _this$state.placeholder,
          helpText = _this$state.helpText,
          subType = _this$state.subType,
          regex = _this$state.regex,
          regexErrMsg = _this$state.regexErrMsg,
          visibility = _this$state.visibility,
          uuid = _this$state.uuid,
          type = _this$state.type,
          parentId = _this$state.parentId;
      var newField = {
        name: name,
        machineName: machineName,
        order: order,
        uuid: uuid,
        type: type,
        parentId: parentId,
        config: {
          conditionalLogic: conditionalLogic,
          isConditionalEnabled: !!conditionalLogic.conditions.length,
          isRequired: isRequired,
          isRichText: isRichText,
          maxLength: maxLength,
          placeholder: placeholder,
          helpText: helpText,
          subType: subType,
          regex: regex,
          regexErrMsg: regexErrMsg,
          visibility: visibility
        }
      };
      var data = {
        field: newField
      };
      newField.locals = processLocalFields(_this.props.locals, _this.state);
      data.locals = processLocalFields(_this.props.locals, _this.state);
      ValidateField(newField, _this.props.fields, _this.props.currentLang).then( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _this.props.updateField(newField);

                _context.next = 3;
                return axios.post(_this.props.predefinedEndpoint + "/form/field/" + _this.props.formId, data);

              case 3:
                // await  axios.post(` ${this.props.predefinedEndpoint}/v2/form/field/${this.props.formId}`, data);
                _this.props.disableFieldEdit();

                _this.setState(_extends({}, _this.state, {
                  isSaving: false
                }));

              case 5:
              case "end":
                return _context.stop();
            }
          }
        }, _callee);
      })))["catch"](function (errors) {
        var keys = Object.keys(errors);

        if (keys[0] === 'machineName' || keys[0] === 'conditionalLogic' || keys[0] === 'regex') {
          _this.handleTabChange({}, 'advance');
        } else {
          _this.handleTabChange({}, 'basic');
        }

        _this.setState({
          errors: errors,
          isSaving: false
        });
      });
    });

    _defineProperty(_assertThisInitialized(_this), "cancelEdit", function () {
      _this.props.deleteNewField();

      _this.props.disableFieldEdit();
    });

    _defineProperty(_assertThisInitialized(_this), "renderTabFields", function () {
      if (_this.state.activeTab === 'basic') {
        if (_this.state.subType === 'number' || _this.state.subType === 'email') {
          textFieldsConfigs.isRichText.configs.hidden = true;
        } else {
          textFieldsConfigs.isRichText.configs.hidden = false;
        }

        return /*#__PURE__*/React.createElement("div", {
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 153,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement(FieldRenderer, _extends({}, _this.state, {
          locals: _this.props.locals,
          fieldConfigs: textFieldsConfigs,
          handleDataChange: _this.handleDataChange,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 154,
            columnNumber: 13
          }
        })));
      } else {
        return /*#__PURE__*/React.createElement("div", {
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 164,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 165,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.machineName,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'machineName');
          },
          label: machineNameLabel[_this.props.currentLang],
          required: true,
          autoFocus: true,
          error: _this.state.errors.machineName,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 166,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 168,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.regex,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'regex');
          },
          label: validationRegexLabel[_this.props.currentLang],
          required: false,
          error: _this.state.errors.regex,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 169,
            columnNumber: 13
          }
        })), _this.state.regex && _this.state.regex !== '' ? /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 172,
            columnNumber: 13
          }
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.regexErrMsg,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'regexErrMsg');
          },
          label: "Regex Validation Error Msg",
          required: false,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 173,
            columnNumber: 15
          }
        })) : "", /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 176,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(SearchableSelect, {
          options: [{
            label: visibleLabel[_this.props.currentLang],
            value: 'visible'
          }, {
            label: hiddenLabel[_this.props.currentLang],
            value: 'hidden'
          }],
          label: visibilityLabel[_this.props.currentLang],
          value: _this.state.visibility ? 'visible' : 'hidden',
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value === 'visible', 'visibility');
          },
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 177,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement(ConditionalLogic, {
          predefined: _this.props.predefined,
          conditionalLogic: _this.state.conditionalLogic,
          isConditionalEnabled: _this.state.isConditionalEnabled,
          handleChange: _this.handleDataChange,
          errors: _this.state.errors.conditionalLogic ? _this.state.errors.conditionalLogic : [],
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 179,
            columnNumber: 11
          }
        }));
      }
    });

    _this.state = _extends({
      activeTab: 'basic',
      errors: {},
      uuid: props.data.uuid,
      name: props.data.name,
      order: props.data.order,
      type: props.data.type,
      parentId: props.data.parentId,
      machineName: props.data.machineName,
      isSaving: false
    }, props.data.config);
    return _this;
  }

  var _proto = TextField.prototype;

  _proto.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    if (nextProps.data.uuid !== this.state.uuid) {
      this.setState(_extends({
        activeTab: 'basic',
        errors: {},
        uuid: nextProps.data.uuid,
        name: nextProps.data.name,
        order: nextProps.data.order,
        type: nextProps.data.type,
        parentId: nextProps.data.parentId,
        machineName: nextProps.data.machineName,
        isSaving: false
      }, nextProps.data.config));
    }
  };

  _proto.render = function render() {
    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 187,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement(SimpleTabs, {
      value: this.state.activeTab,
      handleChange: this.handleTabChange,
      options: [{
        label: basicTabTitle[this.props.currentLang],
        value: 'basic'
      }, {
        label: advanceTabTitle[this.props.currentLang],
        value: 'advance'
      }],
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 188,
        columnNumber: 9
      }
    }), /*#__PURE__*/React.createElement(Scrollbars, {
      style: {
        height: getHeight(true, true)
      },
      autoHide: true,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 189,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "ahfb-p-3 ahfb-my-3",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 190,
        columnNumber: 11
      }
    }, this.renderTabFields(), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-width-full ahfb-text-right",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 192,
        columnNumber: 13
      }
    }, /*#__PURE__*/React.createElement(Button, {
      variant: "outlined",
      className: "ahfb-mr-2",
      onClick: this.cancelEdit,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 193,
        columnNumber: 15
      }
    }, cancelLabel[this.props.currentLang]), /*#__PURE__*/React.createElement(Button, {
      variant: "contained",
      disableElevation: true,
      disabled: this.state.isSaving,
      onClick: this.saveField,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 196,
        columnNumber: 15
      }
    }, saveLabel[this.props.currentLang])))));
  };

  return TextField;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    fields: state.form.data,
    operation: state.toolbar.operation,
    predefined: state.form.predefined,
    locals: state.form.locals,
    formId: state.form.formId,
    predefinedEndpoint: state.form.predefinedEndpoint,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    },
    deleteNewField: function deleteNewField() {
      return dispatch(_deleteNewField());
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    updateField: function updateField(data) {
      return dispatch(_updateField(data));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(TextField);
